@@ -1,7 +1,8 @@
 import { css } from '@emotion/css';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { useStyles2 } from '@grafana/ui/';
+import { t } from '@grafana/i18n';
+import { useStyles2 } from '@grafana/ui';
 import { UpgradeBox, UpgradeContentVertical } from 'app/core/components/Upgrade/UpgradeBox';
 
 export function UpgradeReport() {
@@ -14,9 +15,10 @@ export function UpgradeReport() {
         image={'reporting-email.png'}
         featureName={'reporting'}
         featureUrl={'https://grafana.com/docs/grafana/latest/enterprise/reporting'}
-        description={
+        description={t(
+          'reports.upgrade-report.description-reporting-allows-automatically-generate-dashboards-grafana',
           'Reporting allows you to automatically generate PDFs from any of your dashboards and have Grafana email them to interested parties on a schedule.'
-        }
+        )}
       />
     </div>
   );
